@@ -49,6 +49,11 @@
 #include "config.h"
 #endif
 
+#ifdef IRIX_65
+#include <bstring.h>
+#include <sys/select.h>		/* select() */
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -68,6 +73,13 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
+#ifdef IRIX_65
+struct timeval {
+	time_t	tv_sec;		/* seconds */
+	long	tv_usec;	/* and microseconds */
+};
+#endif
+
 #ifndef SO_RCVTIMEO
 #include <setjmp.h>
 #include <signal.h>
