@@ -1,8 +1,3 @@
-
-#ifndef lint
-static char rcsId[] = "$Header$";
-#endif	/* lint */
-
 /*
  * Cookie support for the simple HTTP library.
  * 
