@@ -334,24 +334,20 @@ typedef enum{
 #define FONT_FIXED		(1<<5)
 #define FONT_SCALABLE	(1<<6)
 
-/*****
-* Supported font types
-*****/
-#define XmHTML_FONT		(1<<1)
-#define XmHTML_FONTSET	(1<<2)
 
 /*****
 * A XmHTML font. XmHTML uses it's own font definition for performance
 * reasons (the layout routines use a *lot* of font properties).
 *****/
 typedef struct _XmHTMLFont{
-	Byte type;					/* font type, XFontStruct or XFontSet		*/
+	XmFontType type;					/* font type, XFontStruct or XFontSet or Xft		*/
 	Byte style;					/* this font's style						*/
 	String font_name;			/* full XLFD								*/
 	String font_family;			/* fontFamily (foundry-family-sw-spacing)	*/
 	XtPointer xfont;			/* ptr to font definition					*/
 								/* Can be a XFontSet when the library was	*/
 								/* compiled with full I18N support.			*/
+								/* Can be a XFT-font  			*/
 	/* font properties */
 	int ptsize;					/* font pointsize							*/
 	int height;					/* height of largest character				*/
@@ -373,6 +369,7 @@ typedef struct _XmHTMLFont{
 	short m_descent;			/* maximum character descent				*/
 	short ascent;				/* average character ascent					*/
 	short descent;				/* average character descent				*/
+	char charset;
 }XmHTMLfont;
 
 /**********
@@ -781,6 +778,8 @@ typedef struct _XmHTMLTable{
 	struct _XmHTMLObjectTable *owner;	/* owner of this table		*/
 
 	struct _XmHTMLTable *next;			/* ptr to next table		*/
+
+	unsigned int debug_id;
 }XmHTMLTable;
 
 /*****
@@ -1167,11 +1166,16 @@ typedef struct _XmHTMLPart {
 	GC					bg_gc;			/* background render gc */
 
 	/* Font resources */
+	XmFontType 			font_type;
 	String				charset;
 	String				font_family;
 	String				font_family_fixed;
+	String				xft_font_family;
+	String				xft_font_family_fixed;
 	String				font_sizes;
 	String				font_sizes_fixed;
+	float 				textHeightFactor;
+	float 				textHeightFactorFixed;
 	XmHTMLfont			*default_font;
 	Byte				string_direction;
 	Byte				alignment;
@@ -1323,6 +1327,8 @@ typedef struct _XmHTMLPart {
 
 	/* Table resources */
 	XmHTMLTable			*tables;		/* list of all tables */
+	int			minColPadding;
+	int			additionalHorizontalTextPaddingInTables;
 
 	/* Embedded object resources */
 	XmHTMLExtObj		*embedded;		/* list of embedded objects */
