@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/XmImage.c,v 1.6 1998/04/27 06:58:06 newt Exp newt $";
-#endif
 /*****
 * XmImage.c : external XmImage routines
 *
@@ -348,7 +345,6 @@ infoToImage(Widget w, XmImageInfo *image_info, Dimension width,
 	_XmHTMLFreeImageInfo((XmHTMLWidget)w, image_info, False);
 	free(html_image);
 	html_image = NULL;
-	image_info = NULL;
 
 	/* see if we have to create a GC for this image */
 	if(_xmimage_cfg && (_xmimage_cfg->flags & ImageCreateGC))
@@ -566,7 +562,7 @@ XmImageCreateFromInfo(Widget w, XmImageInfo *info, Dimension width,
 			gc = image->gc;
 		else
 		{
-			gc = tka->CreateGC(tka->dpy, tka->win, 0, 0);
+			gc = tka->CreateGC(tka, tka->win, 0, 0);
 			tka->SetFunction(tka->dpy, gc, tka->gc_func[GC_GXcopy]);
 		}
 
@@ -580,8 +576,7 @@ XmImageCreateFromInfo(Widget w, XmImageInfo *info, Dimension width,
 					image->height);
 
 			/* set clipmask */
-			tka->SetClipOrigin(tka->dpy, gc, 0, 0);
-			tka->SetClipMask(tka->dpy, gc, image->clip);
+			tka->SetClipOriginAndMask(tka, gc, 0, 0, image->clip);
 
 			/* and copy original pixmap to the new pixmap */
 			tka->CopyArea(tka->dpy, image->pixmap, pixmap, gc, 0, 0,
@@ -603,7 +598,7 @@ XmImageCreateFromInfo(Widget w, XmImageInfo *info, Dimension width,
 
 			XtVaGetValues(w, XmNforeground, &fg, NULL);
 
-			tka->SetClipMask(tka->dpy, gc, None);
+			tka->SetClipOriginAndMask(tka, gc, 0, 0, None);
 			tka->SetForeground(tka->dpy, gc, fg);
 			tka->SetBackground(tka->dpy, gc, _xmimage_cfg->bg_color);
 		}
@@ -673,8 +668,6 @@ XmImageDestroy(XmImage *image)
 	free(image->file);
 
 	free(image);
-
-	image = NULL;
 }
 
 /*****
