@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/forms.c,v 1.9 1998/04/27 06:59:30 newt Exp newt $";
-#endif
 /*****
 * forms.c : XmHTML form support
 *
@@ -1912,7 +1909,7 @@ void _XmHTMLFormReset(XmHTMLWidget html, XmHTMLForm *entry)
 				{
 					Widget menu = NULL;
 					WidgetList children;
-					int i, num_children;
+					int num_children;
 					XmHTMLForm *opt;
 					XtVaGetValues(tmp->w, XmNsubMenuId, &menu, NULL);
 
@@ -1926,7 +1923,7 @@ void _XmHTMLFormReset(XmHTMLWidget html, XmHTMLForm *entry)
 						XmNmenuHistory, children[tmp->selected], NULL);
 
 					/* reset default selection state */
-					for(opt = tmp->options; opt != NULL; opt = opt->next, i++)
+					for(opt = tmp->options; opt != NULL; opt = opt->next)
 					{
 						if(opt->w == children[tmp->selected])
 							opt->checked = True;
@@ -2309,13 +2306,7 @@ _XmHTMLProcessTraversal(Widget w, int direction)
 Boolean
 _XmHTMLFormCreateClipmask(XmHTMLWidget html)
 {
-	XmHTMLFormData *form, *master;
-	XmHTMLForm *entry;
-	ToolkitAbstraction *tka = HTML_ATTR(tka);
-	int lx = 0xfffffff, ly = 0xfffffff;
-	int rx = 0, ry = 0;
-	int nfound = 0;
-	GC tmpGC;
+	XmHTMLFormData *master;
 
 	master = HTML_ATTR(form_data);
 
@@ -2329,6 +2320,13 @@ _XmHTMLFormCreateClipmask(XmHTMLWidget html)
 	return(False);
 
 #if 0
+	GC tmpGC;
+	int nfound = 0;
+	XmHTMLFormData *form;
+	XmHTMLForm *entry;
+	ToolkitAbstraction *tka = HTML_ATTR(tka);
+	int lx = 0xfffffff, ly = 0xfffffff;
+	int rx = 0, ry = 0;
 
 	/* release any previous clipmask */
 	FreePixmap(tka->dpy, master->clip);
@@ -2410,7 +2408,7 @@ _XmHTMLFormCreateClipmask(XmHTMLWidget html)
 	}
 
 	/* temporary gc */
-	tmpGC = tka->CreateGC(tka->dpy, master->clip, 0, 0);
+	tmpGC = tka->CreateGC(tka, master->clip, 0, 0);
 
 	/* initially everything is drawn */
 	tka->SetForeground(tka->dpy, tmpGC, 1);
