@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/frames.c,v 1.10 1998/04/27 06:59:39 newt Exp newt $";
-#endif
 /*****
 * frames.c : XmHTML frame support
 *
@@ -909,7 +906,6 @@ destroyFrameSets(frameSet *set)
 		free(set);
 		set = tmp;
 	}
-	set = NULL;
 }
 
 /*****
@@ -983,7 +979,6 @@ frameDestroyCallback(XmHTMLWidget html, XmHTMLFrameWidget *frame)
 	if(frame->frame)
 		HTML_ATTR(tka)->DestroyWidget(frame->frame);
 	free(frame);
-	frame = NULL;
 }
 
 static void
@@ -1016,10 +1011,10 @@ recursiveDestroyFrameset(XmHTMLFrameWidget *frame)
 		frame->frameset = NULL; /* sanity */
 
 		free(frame);
-		frame = NULL ;
 	}
 }
 
+/*
 static Boolean
 areAllSizesOptional(XmHTMLFrameWidget *frameset)
 {
@@ -1078,6 +1073,7 @@ relativeSizesSum(XmHTMLFrameWidget *frameset)
 	}
 	return(rel_sum);
 }
+*/
 
 /********
 ****** Public Functions
@@ -1282,7 +1278,6 @@ _XmHTMLCreateFrames(XmHTMLWidget old, XmHTMLWidget html)
 {
 	int i;
 	XmHTMLObject *tmp;
-	static Widget frame;
 
 	frame_stack = &frame_base;
 	frame_stack->next = NULL;
@@ -1303,8 +1298,6 @@ _XmHTMLCreateFrames(XmHTMLWidget old, XmHTMLWidget html)
 	if(html == NULL || !html->html.frame_callback || html->html.nframes == 0)
 		return(False);
 
-	frame = NULL;
-
 	/* create the list of HTML frame childs */
 	html->html.frames = (XmHTMLFrameWidget**)calloc(html->html.nframes,
 		sizeof(XmHTMLFrameWidget*));
