@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/motif.c,v 1.2 1998/04/27 07:01:23 newt Exp newt $";
-#endif
 /*****
 * tka-motif.c : XmHTML/Motif ToolkitAbstraction
 *
@@ -58,6 +55,11 @@ static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/motif.c,v 1.2 1998/
 #include <Xm/ScrolledW.h>
 #include <Xm/RepType.h>
 
+#include <X11/Xlib.h>
+#ifdef HAVE_XFT
+#include <X11/Xft/Xft.h>
+#endif
+
 /* Our private header files */
 #include "toolkit.h"
 #include XmHTMLPrivateHeader
@@ -80,7 +82,7 @@ static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/motif.c,v 1.2 1998/
 * doesn't.
 *****/
 
-#ifdef I18N
+
 /*****
 * Name:			I18NTextWidth
 * Return Type: 	int
@@ -94,11 +96,14 @@ static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/motif.c,v 1.2 1998/
 *	pixel width of given string.
 *****/
 static int
-I18NTextWidth(XmHTMLfont *font, const char* string, int count)
+I18NTextWidth(struct _ToolkitAbstraction* tka, XmHTMLfont *font, const char* string, int count)
 {
+#ifdef HAVE_XFT
+	Display* display = tka->dpy;
+#endif
 	switch(font->type)
 	{
-		case XmHTML_FONT:
+		case XmFONT_IS_FONT:
 			{
 				XFontStruct *xfont = (XFontStruct*)font->xfont;
 
@@ -112,13 +117,29 @@ I18NTextWidth(XmHTMLfont *font, const char* string, int count)
 					return(XTextWidth16(xfont, (XChar2b*)string, count/2));
 			}
 			break;
-		case XmHTML_FONTSET:
+#ifdef I18N
+		case XmFONT_IS_FONTSET:
 			/*****
 			* A Fontset indicates the string to be rendered is a multibyte
 			* string. Act accordingly.
 			*****/
 			return(XmbTextEscapement((XFontSet)font->xfont, string, count));
 			break;
+#endif
+#ifdef HAVE_XFT
+		case XmFONT_IS_XFT:
+			{
+				XftFont* xftFont = (XftFont*)font->xfont;
+				XGlyphInfo extents;
+				if ( tka->charset != NULL && strcasecmp( tka->charset, "UTF-8" ) == 0 ) {
+					XftTextExtentsUtf8( display, xftFont, (const FcChar8 *)string, count, &extents );
+				} else {
+					XftTextExtents8( display, xftFont, (const FcChar8 *)string, count, &extents );
+				}
+				return extents.xOff;
+			}
+			break;
+#endif
 	}
 	_XmHTMLError(__WFUNC__(NULL, "I18NTextWidth"),
 		"Unknown fontset type %i", font->type);
@@ -127,6 +148,111 @@ I18NTextWidth(XmHTMLfont *font, const char* string, int count)
 	return(0);
 }
 
+/*****
+* Name:			I18NTextExtents
+* Return Type: 	int
+* Description: 	full I18N version for computing the text extents of a given string
+* In: 
+*	font:		font to be used when computing pixel width;
+*	string:		string for which to compute pixel width;
+*	count:		no of characters in string.
+* Returns:
+*	pixel width of given string.
+*****/
+static int
+I18NTextExtents(struct _ToolkitAbstraction* tka, XmHTMLfont *font, const char* string, int count,
+		int* direction_return,
+		int* font_ascent_return,
+		int* font_descent_return,
+		XCharStruct* overall_return
+)
+{
+#ifdef HAVE_XFT
+	Display* display = tka->dpy;
+#endif
+
+	switch(font->type)
+	{
+		case XmFONT_IS_FONT:
+			{
+				XFontStruct *xfont = (XFontStruct*)font->xfont;
+
+				/*****
+				* If this is a two-byte font, assume that the given
+				* string consists of two-byte characters.
+				*****/
+				if((xfont->min_byte1 == 0) && (xfont->max_byte1 == 0))
+				{
+					return 
+						XTextExtents(
+							xfont, string, count, 
+							direction_return, font_ascent_return, font_descent_return, overall_return
+						);
+				}
+				else
+				{
+					return 
+						XTextExtents16(
+							xfont, (XChar2b*)string, count/2, 
+							direction_return, font_ascent_return, font_descent_return, overall_return
+						);
+				}
+			}
+			break;
+#ifdef I18N
+#if 0 /* was not supported before */
+		case XmFONT_IS_FONTSET:
+			/*****
+			* A Fontset indicates the string to be rendered is a multibyte
+			* string. Act accordingly.
+			*****/
+			XmbTextExtents((XFontSet)font->xfont, string, count, ...);
+			...TODO...
+			break;
+#endif
+#endif
+#ifdef HAVE_XFT
+		case XmFONT_IS_XFT:
+			{
+				XftFont* xftFont = (XftFont*)font->xfont;
+				XGlyphInfo extents;
+				if ( tka->charset != NULL && strcasecmp( tka->charset, "UTF-8" ) == 0 ) {
+					XftTextExtentsUtf8( display, xftFont, (const FcChar8 *)string, count, &extents );
+				} else {
+					XftTextExtents8( display, xftFont, (const FcChar8 *)string, count, &extents );
+				}
+				if ( direction_return != NULL ) {
+					if ( extents.xOff >= 0 ) {
+						*direction_return = FontLeftToRight;
+					} else {
+						*direction_return = FontRightToLeft;
+					}
+				}
+				if ( font_ascent_return != NULL ) {
+					*font_ascent_return = xftFont->ascent;
+				}
+				if ( font_descent_return != NULL ) {
+					*font_descent_return = xftFont->descent;
+				}
+				if ( overall_return != NULL ) {
+					overall_return->lbearing = extents.x;
+					overall_return->rbearing = extents.x + extents.width;
+					overall_return->width = extents.xOff;
+					overall_return->ascent = extents.y;
+					overall_return->descent = extents.height - extents.y;
+				}
+				return 0;
+			}
+			break;
+#endif
+	}
+	_XmHTMLError(__WFUNC__(NULL, "I18NTextExtents"),
+		"Unknown fontset type %i", font->type);
+
+	/* not reached */
+	return(0);
+}
+
 /*****
 * Name:			I18NDrawString
 * Return Type: 	int
@@ -144,12 +270,14 @@ I18NTextWidth(XmHTMLfont *font, const char* string, int count)
 *	nothing.
 *****/
 static int
-I18NDrawString(Display *display, Drawable drawable, XmHTMLfont *font,
+I18NDrawString(struct _ToolkitAbstraction* tka, XmHTMLfont *font,
 	GC gc, int x, int y, const char *string, int length)
 {
+	Display* display = tka->dpy;
+	Drawable drawable = tka->win;
 	switch(font->type)
 	{
-		case XmHTML_FONT:
+		case XmFONT_IS_FONT:
 			{
 				XFontStruct *xfont = (XFontStruct*)font->xfont;
 				static Font fid;
@@ -171,10 +299,51 @@ I18NDrawString(Display *display, Drawable drawable, XmHTMLfont *font,
 						length / 2);
 			}
 			return(1);
-		case XmHTML_FONTSET:
+#ifdef I18N
+		case XmFONT_IS_FONTSET:
 			XmbDrawString(display, drawable, (XFontSet)font->xfont, gc, x, y,
 				string, length);
 			return(1);
+#endif
+#ifdef HAVE_XFT
+		case XmFONT_IS_XFT: 
+			{
+				XftDraw* draw = tka->xftDrawOfWin;
+				XftFont* xftFont = (XftFont*)font->xfont;
+
+				/* get the foreground color from the gc */
+				XGCValues gcValues;
+				XGetGCValues( display, gc, GCForeground, &gcValues );
+				Pixel foregroundPixel = gcValues.foreground;
+				/* convert the pixel value to an XColor */
+				/* TODO: This involves a roundtrip to the X-Server. So, there should be some caching. */
+				XColor foregroundXColor;
+				foregroundXColor.pixel = foregroundPixel;
+				XQueryColor( display, tka->colormap, &foregroundXColor );
+				/* convert the XColor to an XftColor */
+				XftColor foregroundXftColor;
+				foregroundXftColor.color.red = foregroundXColor.red;
+				foregroundXftColor.color.green = foregroundXColor.green;
+				foregroundXftColor.color.blue = foregroundXColor.blue;
+				foregroundXftColor.color.alpha = 0xffff;
+				foregroundXftColor.pixel = foregroundPixel;
+
+				/* TODO: clip mask: maybe as follows: Wrap the GC with a new struct XmHTML_GC. 
+					The XmHTML_GC also contains an XftDraw which is computed by lazy eval and updated
+					along with the GC ( e.g. clipmask ). This may also be a place to put the cache for XQueryColor */
+
+				if ( tka->charset != NULL && strcasecmp( tka->charset, "UTF-8" ) == 0 ) {
+					XftDrawStringUtf8(
+						draw, &foregroundXftColor, xftFont, x, y, (const FcChar8*)string, length
+					);
+				} else {
+					XftDrawString8(
+						draw, &foregroundXftColor, xftFont, x, y, (const FcChar8*)string, length
+					);
+				}
+			}
+			return(1);
+#endif
 	}
 	_XmHTMLError(__WFUNC__(NULL, "I18NDrawString"),
 		"Unknown fontset type %i", font->type);
@@ -183,8 +352,7 @@ I18NDrawString(Display *display, Drawable drawable, XmHTMLfont *font,
 	return(0);
 }
 
-#else /* I18N */
-
+#if 0 /* old code for without I18N */
 /*****
 * Name:			I18NTextWidth
 * Return Type: 	int
@@ -238,7 +406,7 @@ I18NDrawString(Display *display, Drawable drawable, XmHTMLfont *font,
 	}
 	return(XDrawString(display, drawable, gc, x, y, string, length));
 }
-#endif /* I18 N */
+#endif
 
 /*****
 * Name:			XSetFont_wrapper
@@ -278,7 +446,7 @@ DestroyImage(XImage *image)
 }
 
 static unsigned long
-GetPixelWrapper(XImage *ximage, Dimension x, Dimension y)
+GetPixelWrapper(XImage *ximage, _XtDimension x, _XtDimension y)
 {
 	return(XGetPixel(ximage, x, y));
 }
@@ -331,6 +499,28 @@ _XmHTMLDrawShadows(Display *display, Drawable drawable, GC top_shadow_GC,
 }
 #endif
 
+
+static GC XmHTML_CreateGC( 
+	struct _ToolkitAbstraction* tka,
+	Drawable d,
+	unsigned long valuemask,
+	XGCValues* values
+) {
+	return XCreateGC( tka->dpy, d, valuemask, values );
+}
+
+static int XmHTML_SetClipOriginAndMask(
+	struct _ToolkitAbstraction* tka,
+	GC gc,
+	int clip_x_origin,
+	int clip_y_origin,
+	Pixmap pixmap
+) {
+	XSetClipOrigin( tka->dpy, gc, clip_x_origin, clip_y_origin );
+	XSetClipMask( tka->dpy, gc, pixmap );
+	return(1);
+}
+
 static ToolkitAbstraction*
 _CreateMotifTka(void)
 {
@@ -339,10 +529,22 @@ _CreateMotifTka(void)
 	tka = (ToolkitAbstraction*)malloc(sizeof(ToolkitAbstraction));
 
 	tka->dpy = NULL;
+	tka->screen = NULL;
 	tka->win = None;
+#ifdef HAVE_XFT
+	tka->xftDrawOfWin = NULL;
+#endif
 	tka->defaultRoot = None;
 
+	tka->font_type = XmFONT_IS_FONT;
+	tka->visual = NULL;
+	tka->colormap = None;
+	tka->charset = NULL;
+
+
 	/* GC properties */
+	tka->clipRegion = 0;
+
 	tka->fill_style[GC_FILL_SOLID]           = FillSolid;
 	tka->fill_style[GC_FILL_TILED]           = FillTiled;
 	tka->fill_style[GC_FILL_STIPPLED]        = FillStippled;
@@ -368,12 +570,15 @@ _CreateMotifTka(void)
 	tka->gc_func[GC_GXcopy] = GXcopy;
 
 	/* GC functions */
-	tka->CreateGC      = XCreateGC;
+	tka->CreateGC      = XmHTML_CreateGC;
 	tka->FreeGC        = XFreeGC;
 	tka->CopyGC        = XCopyGC;
 	tka->SetFunction   = XSetFunction;
+	tka->SetClipOriginAndMask   = XmHTML_SetClipOriginAndMask;
+#if 0
 	tka->SetClipMask   = XSetClipMask;
 	tka->SetClipOrigin = XSetClipOrigin;
+#endif
 	tka->SetTile       = XSetTile;
 	tka->SetTSOrigin   = XSetTSOrigin;
 	tka->SetFillStyle  = XSetFillStyle;
@@ -416,7 +621,7 @@ _CreateMotifTka(void)
 
 	/* string/text functions */
 	tka->TextWidth     = I18NTextWidth;
-	tka->TextExtents   = XTextExtents;
+	tka->TextExtents   = I18NTextExtents; /* was XTextExtents */
 
 	/* Render functions */
 	tka->DrawString    = I18NDrawString;
@@ -525,6 +730,7 @@ XmHTMLTkaCopy(ToolkitAbstraction *tka)
 	return(tka_ret);
 }
 
+
 /*****
 * Name: 
 * Return Type: 
@@ -538,6 +744,22 @@ void
 XmHTMLTkaSetDrawable(ToolkitAbstraction *tka, Drawable drawable)
 {
 	tka->win = drawable;
+#ifdef HAVE_XFT
+	/* manage the corresponding xftDraw */
+	if ( tka->font_type == XmFONT_IS_XFT ) {
+		if ( tka->xftDrawOfWin != NULL ) {
+			XftDrawDestroy(tka->xftDrawOfWin);
+			tka->xftDrawOfWin = NULL;
+		}
+		tka->xftDrawOfWin = 
+			XftDrawCreate(
+				tka->dpy,
+				tka->win,
+				tka->visual,
+				tka->colormap
+			);
+	}
+#endif
 }
 
 /*****
@@ -553,6 +775,10 @@ void
 XmHTMLTkaSetDisplay(ToolkitAbstraction *tka, Widget w)
 {
 	tka->dpy = XtDisplay(w);
+	tka->screen = XtScreen(w);
+
+	tka->visual = XDefaultVisualOfScreen(tka->screen);
+	tka->colormap = XDefaultColormapOfScreen(tka->screen);
 
 	/* and set display dimensions (we use it determine the dpi of the screen)*/
 	tka->width    = DisplayWidth(tka->dpy, DefaultScreen(tka->dpy));
