@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/map.c,v 1.11 1998/04/27 07:00:22 newt Exp newt $";
-#endif
 /*****
 * map.c : XmHTML imagemap routines
 *
@@ -711,16 +708,11 @@ void
 _XmHTMLDrawImagemapSelection(XmHTMLWidget html, XmHTMLImage *image)
 {
 	XmHTMLImageMap *map;
-	int xs, ys;
 	mapArea *area;
 
 	if((map = _XmHTMLGetImagemap(html, image->map_url)) == NULL)
 		return;
 
-	/* map coordinates to upperleft corner of image */
-	xs = html->html.scroll_x - image->owner->x;
-	ys = html->html.scroll_y - image->owner->y;
-
 	area = map->areas;
 
 	while(area)
@@ -847,7 +839,6 @@ _XmHTMLFreeImageMaps(XmHTMLWidget html)
 	{
 		map = map_list->next;
 		freeImageMap(map_list);
-		map_list = NULL;
 		map_list = map;
 	}
 	html->html.image_maps = NULL;
@@ -872,7 +863,6 @@ void
 _XmHTMLCheckImagemaps(XmHTMLWidget html)
 {
 	XmHTMLImage *image;
-	XmHTMLImageMap *imagemap;
 
 	_XmHTMLDebug(10, ("map.c: _XmHTMLCheckImagemaps Start\n"));
 
@@ -888,7 +878,7 @@ _XmHTMLCheckImagemaps(XmHTMLWidget html)
 	{
 		if(image->map_url != NULL)
 		{
-			if((imagemap = _XmHTMLGetImagemap(html, image->map_url)) == NULL)
+			if(NULL == _XmHTMLGetImagemap(html, image->map_url))
 			{
 				static XmHTMLImagemapCallbackStruct cbs;
 
