@@ -47,8 +47,15 @@
 #include <string.h>
 #include <ctype.h>
 
-#include <png.h> /* must be included before Xft because it would create build problems if it were included afterwards. ( it is indirectly included by plc.h ) */
+#ifdef HAVE_XFT
+/* png.h must be included before Xft because it would create build 
+   problems if it were included afterwards as it is indirectly included 
+   by plc.h 
+*/
+#include <png.h> 
 #include <X11/Xft/Xft.h>
+#endif
+
 #include <X11/Xlib.h>
 
 /* Our private header files */
@@ -317,7 +324,7 @@ _XmHTMLRefresh(XmHTMLWidget html, int x, int y, int width, int height)
 	if(HTML_ATTR(gc) == NULL)
 		return;
 
-#if 0
+#if 0 /* old code for direct rendering of XFT into the window */
 	/* set clip mask for Xft-Strings in order to avoid multiple redraw of antialiased fonts (which looks ugly) */
 	if(tka != NULL && tka->xftDrawOfWin != NULL ) {
 		XRectangle clipRectangle;
@@ -343,33 +350,36 @@ _XmHTMLRefresh(XmHTMLWidget html, int x, int y, int width, int height)
 		XFreeGC( tka->dpy, gc );
 	}
 
+#if HAVE_XFT
 	/* redirect XFT-drawing, too */
 	if ( tka->xftDrawOfWin != NULL ) {
 		XftDrawChange( tka->xftDrawOfWin, tka->win );
 	}
+#endif
 
 	/* do the actual painting */
 	_XmHTMLDebug(1, ("XmHTML.c: _XmHTMLRefresh, calling _XmHTMLPaint\n"));
 	_XmHTMLPaint(html, HTML_ATTR(paint_start), HTML_ATTR(paint_end));
 
-#if 0
+#if 0 /* old code for direct rendering of XFT into the window */
 	/* clear clipmask for Xft-Strings */
 	if(tka != NULL && tka->xftDrawOfWin != NULL ) {
 		XftDrawSetClip(tka->xftDrawOfWin, 0);
 		XDestroyRegion( tka->clipRegion );
 		tka->clipRegion = 0;
 	}
-#endif
-
 
 	/* redirect XFT-drawing back to the original window */
 	if ( tka->xftDrawOfWin != NULL ) {
 		XftDrawChange( tka->xftDrawOfWin, savedWin );
 	}
+#endif
 
 	/* copy the drawing from the pixmap to the window */
 	{
-		GC gc = XCreateGC( tka->dpy, savedWin, 0, NULL );
+		XGCValues gcAttr;
+		gcAttr.graphics_exposures = 0;
+		GC gc = XCreateGC( tka->dpy, savedWin, GCGraphicsExposures, &gcAttr );
 		XCopyArea( tka->dpy, tka->win, savedWin, gc, x, y, width, height, x, y );
 		XFreeGC( tka->dpy, gc );
 	}
@@ -388,7 +398,6 @@ _XmHTMLRefresh(XmHTMLWidget html, int x, int y, int width, int height)
 
 	/* display scrollbars */
 	_XmHTMLSetScrollBars(html);
-
 }
 
 /*****
