@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header$";
-#endif
 /*****
 * psoutput.c : XmHTML Postscript output routines
 *
@@ -196,7 +193,7 @@ static void PStext(PSDisplay *dpy, String t, Boolean underline);
 static void PScheckPage(PSDisplay *dpy, int x, int y);
 static void PSshowpage(PSDisplay *dpy);
 static void PSmoveto(PSDisplay *dpy, int x, int y);
-static void PSmove_offset(PSDisplay *dpy, int offset);
+/* static void PSmove_offset(PSDisplay *dpy, int offset); */
 static int PSencode(unsigned char *data, unsigned char *rle, int size);
 static void PSfootnotes(PSDisplay *dpy);
 static int PShex(PSDisplay *dpy, Byte val, int flush);
@@ -213,7 +210,7 @@ static ToolkitAbstraction *_CreatePostscriptTka(XmHTMLWidget html);
 
 static int pstkSetForeground(Display *disp, XGC gc, unsigned long foreground);
 static int pstkSetFont(Display *disp, XGC gc, XmHTMLfont *font);
-static int pstkDrawString(Display *disp, DRAWABLE win,
+static int pstkDrawString(struct _ToolkitAbstraction* tka,
 	struct _XmHTMLFont *font, XGC gc, int x, int y, char *string, int length);
 static void pstkDrawAnchorData(Display *disp, WINDOW win, XGC gc, int x,
 	int y, XmHTMLObjectTableElement data);
@@ -1078,6 +1075,7 @@ PSmoveto(PSDisplay *dpy, int x, int y)
 * Returns:
 *	nothing.
 *****/
+/*
 static void
 PSmove_offset(PSDisplay *dpy, int offset)
 {
@@ -1087,6 +1085,7 @@ PSmove_offset(PSDisplay *dpy, int offset)
 		dpy->offset = offset;
 	}
 }
+*/
 
 /*****************************************************************************
 ****************** Image & Color conversion Routines *************************
@@ -1525,7 +1524,6 @@ PSImage(PSDisplay *dpy, XmHTMLImage *image, int x, int y)
 	int h = info->height;
 	int slen, colortype, bits;
 	int err=0;
-	int extra = 0;
 	int dest_x = x, dest_y = 0;
 	Boolean isanchor = False;
 	Boolean colorps = False;
@@ -1570,7 +1568,6 @@ PSImage(PSDisplay *dpy, XmHTMLImage *image, int x, int y)
 			dest_x-2, dest_y-2, w+4, h+4);
 		PSprintf(dpy, "SQ fill\n");
 		PSprintf(dpy, "grestore\n");
-		extra = 4;
 	}
 	
 	/*****
@@ -1734,7 +1731,7 @@ pstkSetForeground(Display *disp, XGC gc, unsigned long foreground)
 }
 
 static GC
-pstkCreateGC(Display *disp, DRAWABLE win, unsigned long valuemask,
+pstkCreateGC(struct _ToolkitAbstraction* tka, DRAWABLE win, unsigned long valuemask,
 	XGCValues *values)
 {
 	return(NULL);
@@ -1759,14 +1756,9 @@ pstkSetFunction(Display *disp, XGC gc, int function)
 }
 
 static int
-pstkSetClipMask(Display *disp, XGC gc, PIXMAP pixmap)
-{
-	return(1);
-}
-
-static int
-pstkSetClipOrigin(Display *disp, XGC gc, int clip_x_origin,
-	int clip_y_origin)
+pstkSetClipOriginAndMask(struct _ToolkitAbstraction* tka, XGC gc, 
+	int clip_x_origin, int clip_y_origin,
+	PIXMAP pixmap)
 {
 	return(1);
 }
@@ -1832,17 +1824,12 @@ pstkSetFont(Display *disp, XGC gc, XmHTMLfont *font)
 * Returns:
 *	pixel width of given string.
 *****/
+/*
 static int
 pstkTextWidth(XmHTMLfont *font, const char* string, int count)
 {
-	char *chPtr;
-	int width = 0;
-	int i = 0;
-
-	for(chPtr = string; i < count; chPtr++, i++)
-	{
-	}
 }
+*/
 
 #if 0
 /*****
@@ -1880,9 +1867,10 @@ pstkCopyArea(Display *disp, DRAWABLE src, DRAWABLE dest, XGC gc, int src_x,
 *	always 1 (ignored by caller)
 *****/
 static int
-pstkDrawString(Display *disp, DRAWABLE win, struct _XmHTMLFont *font,
+pstkDrawString( struct _ToolkitAbstraction* tka, struct _XmHTMLFont *font,
 	XGC gc, int x, int y, char *string, int length)
 {
+	Display *disp = tka->dpy;
 	PSDisplay *dpy = (PSDisplay*)disp;
 	static char *last_ep=NULL;
 	char *ep = string+strlen(string);
@@ -2215,8 +2203,7 @@ _CreatePostscriptTka(XmHTMLWidget html)
 	tka->FreeGC        = pstkFreeGC;
 	tka->CopyGC        = pstkCopyGC;
 	tka->SetFunction   = pstkSetFunction;
-	tka->SetClipMask   = pstkSetClipMask;
-	tka->SetClipOrigin = pstkSetClipOrigin;
+	tka->SetClipOriginAndMask   = pstkSetClipOriginAndMask;
 	tka->SetTile       = pstkSetTile;
 	tka->SetTSOrigin   = pstkSetTSOrigin;
 	tka->SetFillStyle  = pstkSetFillStyle;
