@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/public.c,v 1.1 1998/04/27 06:54:17 newt Exp newt $";
-#endif
 /*****
 * public.c : XmHTML public routines that do not depend on X Intrinsics
 *			 or Motif.
@@ -157,6 +154,46 @@ XmHTMLAnchorScrollToId(Widget w, int anchor_id)
 	}
 }
 
+/*****
+* Name: 		XmHTMLAnchorScrollToYPos
+* Return Type: 	void
+* Description: 	scroll to the given y-position
+* In: 
+*	w:			XmHTMLWidget
+*	ypos:			y-position to scroll to
+* Returns:
+*	nothing.
+*****/
+void
+XmHTMLScrollToYPos(Widget w, int ypos)
+{
+	XmHTMLWidget html;
+
+	/* sanity check */
+	if(!w || !XmIsHTML(w))
+	{
+		_XmHTMLBadParent(w, "XmHTMLAnchorScrollToYPos");
+		return;
+	}
+
+	html = (XmHTMLWidget)w;
+
+	if(HTML_ATTR(needs_vsb))
+	{
+		int value;
+
+		_XmHTMLDebug(1, ("XmHTML.c: XmHTMLAnchorScrollToYPos, "
+			"calling _XmHTMLMoveToPos\n"));
+
+		value = ypos;
+
+		_XmHTMLAdjustVerticalScrollValue(HTML_ATTR(vsb), &value);
+
+		_XmHTMLMoveToPos(HTML_ATTR(vsb), html, value);
+	}
+}
+
+
 /*****
 * Name: 		XmHTMLAnchorScrollToName
 * Return Type: 	void
@@ -479,7 +516,6 @@ XmHTMLTextGetString(Widget w)
 static void
 documentLoadNormal(XmHTMLWidget html, String text, size_t len)
 {
-	Boolean had_hsb, had_vsb;
 	ToolkitAbstraction *tka = HTML_ATTR(tka);
 
 	_XmHTMLDebug(1, ("XmHTML.c: documentLoadNormal, start\n"));
@@ -501,10 +537,6 @@ documentLoadNormal(XmHTMLWidget html, String text, size_t len)
 	if(HTML_ATTR(current_anchor) != NULL)
 		tka->UndefineCursor(tka->dpy, tka->win);
 
-	/* check the current state of the scrollbars */
-	had_hsb = tka->IsManaged(HTML_ATTR(hsb));
-	had_vsb = tka->IsManaged(HTML_ATTR(vsb));
-
 	/* First kill any outstanding PLC's */
 	_XmHTMLKillPLCCycler(html);
 
@@ -733,8 +765,6 @@ XmHTMLTextSetString(Widget w, String text)
 void
 XmHTMLTextSetStringWithLength(Widget w, String text, size_t len)
 {
-	XmHTMLWidget html;
-
 	/* sanity check */
 	if(!w || !XmIsHTML(w))
 	{
@@ -742,9 +772,6 @@ XmHTMLTextSetStringWithLength(Widget w, String text, size_t len)
 		return;
 	}
 
-	/* widget ptr */
-	html = (XmHTMLWidget)w;
-
 #ifdef CANDO_PROGRESSIVE_LOAD
 	switch(HTML_ATTR(load_type))
 	{
@@ -1072,7 +1099,6 @@ XmHTMLImageFreeAllImages(Widget w)
 	{
 		image = image_list->next;
 		_XmHTMLFreeImage(html, image_list);
-		image_list = NULL;
 		image_list = image;
 	}
 	html->html.images = NULL;
