@@ -1,6 +1,3 @@
-#ifndef production
-static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/quantize.c,v 1.7 1998/04/27 07:02:49 newt Exp newt $";
-#endif
 /*****
 * quantize.c : XmHTML color quantization routines
 *
@@ -79,6 +76,12 @@ static char rcsId[]="$Header: /usr/local/rcs/Newt/XmHTML/RCS/quantize.c,v 1.7 19
 
 #define _WANT_TIMINGS	/* we want timings, see debug.h */
 
+#ifdef HAVE_XFT
+#include <X11/Xft/Xft.h>
+#endif
+
+#include <X11/Xlib.h>
+
 #include "toolkit.h"
 #include XmHTMLPrivateHeader
 
@@ -206,7 +209,7 @@ static void
 my_bcopy(char *src, char *dst, size_t len)
 {
 	/* areas are the same */
-	if(src == dst || len <= 0)
+	if(src == dst || len == 0)
 		return;
   
 	if(src < dst && src+len > dst)
