@@ -64,8 +64,15 @@
 #include <zlib.h>
 #endif
 
-#include <png.h> /* must be included before Xft because it would create build problems if it were included afterwards. ( it is indirectly included by plc.h ) */
+#ifdef HAVE_XFT
+/* png.h must be included before Xft because it would create build 
+   problems if it were included afterwards as it is indirectly included 
+   by plc.h 
+*/
+#include <png.h> 
 #include <X11/Xft/Xft.h>
+#endif
+
 #include <X11/Xlib.h>
 
 #include "toolkit.h"
