@@ -1,6 +1,3 @@
-#ifndef lint
-static char rcsId[]="$Header$";
-#endif
 /*****
 * gtk.c : XmHTML/gtk ToolkitAbstraction
 *
@@ -74,7 +71,7 @@ static GdkFont *curr_font = NULL;
 **********/
 
 static GdkGC*
-gdk_gc_new_wrapper(void *display, GdkWindow *drawable,
+gdk_gc_new_wrapper(struct _ToolkitAbstraction* tka, GdkWindow *drawable,
 	GdkGCValuesMask valuemask, GdkGCValues *values)
 {
 	return(gdk_gc_new_with_values(drawable, values, valuemask));
@@ -102,16 +99,12 @@ gdk_gc_set_function_wrapper(void *display, GdkGC *gc, GdkFunction function)
 	gdk_gc_set_function(gc, function);
 }
 
-static void
-gdk_gc_set_clip_mask_wrapper(void *display, GdkGC *gc, GdkBitmap *pixmap)
-{
-	gdk_gc_set_clip_mask(gc, pixmap);
-}
 
 static void
-gdk_gc_set_clip_origin_wrapper(void *display, GdkGC *gc,
-	gint clip_x_origin, gint clip_y_origin)
-{
+gdk_gc_set_clip_origin_and_mask_wrapper(
+	struct _ToolkitAbstraction* tka, GdkGC *gc, gint clip_x_origin, gint clip_y_origin, GdkBitmap *pixmap
+) {
+	/* set clip origin */
 #ifdef NO_GDK_ILLEGAL_ACCESS
 	gdk_gc_set_clip_origin(gc, clip_x_origin, clip_y_origin);
 #else
@@ -119,6 +112,9 @@ gdk_gc_set_clip_origin_wrapper(void *display, GdkGC *gc,
 
 	XSetClipOrigin(pgc->xdisplay, pgc->xgc, clip_x_origin, clip_y_origin);
 #endif
+
+	/* set clip mask */
+	gdk_gc_set_clip_mask(gc, pixmap);		
 }
 
 static void
@@ -653,8 +649,7 @@ _CreateGtkToolkitAbstraction(void)
 	tka->FreeGC        = gdk_gc_destroy_wrapper;
 	tka->CopyGC        = gdk_gc_copy_wrapper;
 	tka->SetFunction   = gdk_gc_set_function_wrapper;
-	tka->SetClipMask   = gdk_gc_set_clipmask_wrapper;
-	tka->SetClipOrigin = gdk_gc_set_clip_origin_wrapper;
+	tka->SetClipOriginAndMask   = gdk_gc_set_clip_origin_and_mask_wrapper;
 	tka->SetTile       = gdk_gc_set_tile_wrapper;
 	tka->SetTSOrigin   = gdk_gc_set_ts_origin_wrapper;
 	tka->SetFillStyle  = gdk_gc_set_fill_wrapper;
