@@ -55,7 +55,9 @@
 #include "toolkit.h"
 #include XmHTMLPrivateHeader
 
+#ifdef HAVE_XPM
 #include <X11/xpm.h>
+#endif
 
 /*** External Function Prototype Declarations ***/
 
@@ -397,8 +399,10 @@ _XmHTMLTextGetPS(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 	int margin_w, margin_h, work_w;
 	ToolkitAbstraction *tka;
 	String buf, ret_val = NULL;
+#ifdef HAVE_XPM
 	XpmAttributes xpm;
 	int xpm_err = XpmSuccess;
+#endif
 	GC gc, bg_gc;
 	int y = 0;
 	XmHTMLObjectTable *pstart, *pend;
@@ -577,8 +581,10 @@ _XmHTMLTextGetPS(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 	int margin_w, margin_h, work_w;
 	ToolkitAbstraction *tka;
 	String buf, ret_val = NULL;
+#ifdef HAVE_XPM
 	XpmAttributes xpm;
 	int xpm_err = XpmSuccess;
+#endif
 	GC gc, bg_gc;
 	int y = 0;
 	XmHTMLObjectTable *pstart, *pend;
@@ -681,6 +687,7 @@ _XmHTMLTextGetPS(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 		/* move to next page */
 		HTML_ATTR(scroll_y) += pdef->height;
 
+#ifdef HAVE_XPM
 		/*****
 		* For now, let xpm create an XPM data buffer from the created
 		* pixmap (libXpm puts the pixmap into an XImage and converts
@@ -739,6 +746,13 @@ _XmHTMLTextGetPS(XmHTMLWidget html, XmHTMLPaperSize *pdef,
 				ret_val = strdup(buf);
 			free(buf);
 		}
+#else
+		fprintf(stderr, "_XmHTMLTextGetPS: XPM: xpm missing error.\n");
+		if(ret_val)
+			free(ret_val);
+		ret_val = NULL;
+		goto done;
+#endif
 	}
 
 done:
