@@ -1127,6 +1127,7 @@ _PLC_IMG_Init(PLC *plc)
 
 #endif /* HAVE_LIBPNG */
 	}
+#ifdef HAVE_XPM
 	else if(!(strncmp((char*)magic, "/* XPM */", 9)))
 	{
 		obj_type = plcXPM;
@@ -1136,6 +1137,7 @@ _PLC_IMG_Init(PLC *plc)
 		plc->obj_funcs[0] = _PLC_XPM_ScanlineProc;
 		plc->object->plc_xpm_image.info = (XmImageInfo*)plc->priv_data;
 	}
+#endif /* HAVE_XPM */
 	else if(!(strncmp((char*)magic, "#define", 7)) ||
 		(magic[0] == '/' && magic[1] == '*'))
 	{
